==> savane-1.0.7+4.tar.gz: savane-1.0.7+4/frontend/php/people/viewprofile.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: viewprofile.php,v 1.18 2004/10/30 02:18:40 sonicmctails Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# FIXME: this page is not a profile but a resume page.

require "../include/pre.php";

if ($user_id) 
{
  site_header(array('title'=>_("User Resume"),'toptab'=>'people'));

  #for security, include user_id
  $sql="SELECT * FROM user WHERE user_id='$user_id'";
  $result=db_query($sql);

  if (!$result || (db_numrows($result) < 1))
    {
      fb(_("User not found"),1);

    } 
  else if (db_result($result,0,'people_view_skills') != 1) 
    {
      fb(_("This user has set his/her profile to private"),1);
    } 
  else 
    {
      # we get site-specific content
      utils_get_content("people/viewprofile");

      print '<h3>'.sprintf(_("Resume of %s"),utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname'))).'</h3>';
      print utils_make_links(nl2br(db_result($result,0,'people_resume'))) ;
      
      print '<br /><br />';
      print '<h3>'.sprintf(_("Skills of %s"),utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname'))).'</h3>';
      print people_show_skill_inventory($user_id);
    }

  print site_footer(array());

}
else 
{
  # user_id not defined :
  exit_missing_param();
}

?>

==> savane-1.2.tar.gz: savane-1.2/frontend/php/people/viewprofile.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: viewprofile.php,v 1.19 2005/06/30 17:19:36 toddy Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
# 
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

# FIXME: this page is not a profile but a resume page.

require "../include/pre.php";

if ($user_id) 
{
  site_header(array('title'=>_("User Resume"),'toptab'=>'people'));

  #for security, include user_id
  $sql="SELECT * FROM user WHERE user_id='$user_id'";
  $result=db_query($sql);

  if (!$result || (db_numrows($result) < 1))
    {
      fb(_("User not found"),1);

    } 
  else if (db_result($result,0,'people_view_skills') != 1) 
    {
      fb(_("This user has set his/her profile to private"),1);
    } 
  else 
    {
      # we get site-specific content
      utils_get_content("people/viewprofile");

      print '<h3>'.sprintf(_("Resume of %s"),utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname'))).'</h3>';
      print utils_make_links(nl2br(db_result($result,0,'people_resume'))) ;
      
      print '<br /><br />';
      print '<h3>'.sprintf(_("Skills of %s"),utils_user_link(db_result($result, $i, 'user_name'),db_result($result, $i, 'realname'))).'</h3>';
      print people_show_skill_inventory($user_id);
    }

  print site_footer(array());

}
else 
{
  # user_id not defined :
  exit_missing_param();
}

?>
